import time

def calculate(function, *args, result=False):
    start_time = time.time()
    result = function(args)
    end_time = time.time()
    the_return = end_time - start_time
    if result:
        return the_return, result
    return the_return


from setuptools import setup


setup(name='speed_calculator',
version='0.4.0',
description="""A library to speed calculation of a function.""",
long_description="""
# Speed Calculator
A library to speed calculation of a function.
# Install
```
pip3 install speed-calculator
```
# Using
```python
from speed_calculator import calculate

import time
def a_function():
    time.sleep(2)

print(calculate(a_function))
```
""",
long_description_content_type='text/markdown',
url='https://github.com/onuratakan/speed_calculator',
author='Onur Atakan ULUSOY',
author_email='atadogan06@gmail.com',
license='MIT',
packages=["speed_calculator"],
package_dir={'':'src'},
python_requires=">= 3",
zip_safe=False)